This feature consists of two types of feature vectors. at first, each protein sequence is divided into
20 equal parts, each of which is called a block, and in each block the row vectors of the PSSM matrix related
to that block are added together and The resulting final vector is divided by the length of that block, which is
5
Finally, by placing these 20 vectors side by side, the first feature vector of length 400 is obtained. The second feature
for each amino acid in each column is the average of the positive numbers in that column and for each block, and these 20
numbers, corresponding to 20 blocks, are placed next to each other, and therefore For each of the 20 types of amino acids,
a vector of length 20 is obtained, and by placing these together, the vector of the second feature, length 400, is obtained.