Learn R Programming

PSSMCOOL (version 0.2.2)

EDP_MEDP: EDP_EEDP_MEDP feature vector

Description

This is a feature vector of length 420 which is used for prediction of protein structural class for low-similarity sequences.at first ED-PSSM Matrix with 20*20 dimensions is constructed from PSSM Matrix then by using this Matrix, EDP and EEDP vectors are obtained eventually MEDP feature vector is obtained by fusing these vectors.

Usage

EDP_MEDP(pssm_name)

Arguments

pssm_name

is name of PSSM Matrix file

Value

a feature vectors of length 420

References

Zhang, L., Zhao, X. and Kong, L. (2014) Predict protein structural class for low-similarity sequences by evolutionary difference information into the general form of Chou's pseudo amino acid composition, Journal of Theoretical Biology, 355, 105-110.

Examples

Run this code
# NOT RUN {
as<-EDP_MEDP(paste0(system.file("extdata",package="PSSMCOOL"),"/C7GS61.txt.pssm"))
# }

Run the code above in your browser using DataLab