Learn R Programming

PSSMCOOL (version 0.2.2)

k_seperated_bigrame: k_seperated_bigrame feature vector

Description

This feature is almost identical to the DPC_PSSM feature, and in fact the DPC feature is part of this feature (for k=1) and for two different columns, considers rows that differ by the size of the unit k.

Usage

k_seperated_bigrame(pssm_name, k)

Arguments

pssm_name

is name of PSSM Matrix file

k

a parameter that specifies separated length between amino acids

Value

a feature vector of length 400

References

Saini, H., et al.(2016) Protein Fold Recognition Using Genetic Algorithm Optimized Voting Scheme and Profile Bigram.

Examples

Run this code
# NOT RUN {
 w<-k_seperated_bigrame(system.file("extdata", "C7GQS7.txt.pssm", package="PSSMCOOL"),5)
# }

Run the code above in your browser using DataLab