The CC variable measures the correlation of two different properties between two residues
separated by a distance of t along the sequence.
Usage
pssm_cc(pssm_name, t)
Arguments
pssm_name
name of PSSM Matrix file
t
shortest protein length in dataset minus one
Value
feature vector of length 380
References
Dong, Q., Zhou, S. and Guan, J. (2009) A new taxonomy-based protein fold recognition approach
based on autocross-covariance transformation, Bioinformatics, 25, 2655-2662.